summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorBryan Bishop <kanzure@gmail.com>2013-11-13 00:28:59 -0600
committerBryan Bishop <kanzure@gmail.com>2013-11-13 00:28:59 -0600
commite4067faa60b58793076da8ff4b4170c4a911822f (patch)
tree05479aa4d8b883f52c836fc0b02d888434de0293
parent51b1f6e642436f1f45c36c86243e58769fe38cd4 (diff)
use the correct wram_labels variable in wram.py
-rw-r--r--pokemontools/wram.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/pokemontools/wram.py b/pokemontools/wram.py
index 80244e3..e1b9212 100644
--- a/pokemontools/wram.py
+++ b/pokemontools/wram.py
@@ -171,11 +171,11 @@ class WRAMProcessor(object):
def reformat_wram_labels(self):
"""
Flips the wram_constants dictionary the other way around to access
addresses by label.
"""
self.wram = {}
- for (address, labels) in self.wram_constants.iteritems():
+ for (address, labels) in self.wram_labels.iteritems():
for label in labels:
self.wram[label] = address
@@ -171,11 +171,11 @@ class WRAMProcessor(object):
def reformat_wram_labels(self):
"""
- Flips the wram_constants dictionary the other way around to access
+ Flips the wram_labels dictionary the other way around to access
addresses by label.
"""